@@ -6,7 +6,7 @@
  *  (the "License"); you may not use this file except in compliance with
  *  the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  *  Unless required by applicable law or agreed to in writing, software
  *  distributed under the License is distributed on an "AS IS" BASIS,
@@ -35,12 +35,12 @@ import org.apache.commons.daemon.DaemonContext;
 public class DaemonWrapper implements Daemon
 {
 
-    private final static String ARGS            = "args";
-    private final static String START_CLASS     = "start";
-    private final static String START_METHOD    = "start.method";
-    private final static String STOP_CLASS      = "stop";
-    private final static String STOP_METHOD     = "stop.method";
-    private final static String STOP_ARGS       = "stop.args";
+    private static final String ARGS            = "args";
+    private static final String START_CLASS     = "start";
+    private static final String START_METHOD    = "start.method";
+    private static final String STOP_CLASS      = "stop";
+    private static final String STOP_METHOD     = "stop.method";
+    private static final String STOP_ARGS       = "stop.args";
     private String              configFileName;
     private final DaemonConfiguration config;
 
